securitysettings/eapqtdialogs/inc/eapdialogplugin.h
changeset 36 c98682f98478
parent 34 ad1f037f1ac2
--- a/securitysettings/eapqtdialogs/inc/eapdialogplugin.h	Thu Jun 24 11:23:08 2010 +0300
+++ b/securitysettings/eapqtdialogs/inc/eapdialogplugin.h	Fri Jul 09 10:14:51 2010 +0300
@@ -16,15 +16,30 @@
 */
 
 /*
-* %version: 3 %
+* %version: 4 %
 */
 
 #ifndef ____EAPDIALOG_H__PLUGIN_H__
 #define ____EAPDIALOG_H__PLUGIN_H__
 
+// System includes
 #include <QObject>
 #include <hbdevicedialogplugin.h>
 
+// User includes
+
+// Forward declarations
+
+// External data types
+
+// Constants
+
+/*!
+   @addtogroup group_eap_dialog_plugin
+   @{
+ */
+
+// Class declaration
 
 class EapDialogPlugin : public HbDeviceDialogPlugin
 {
@@ -37,27 +52,29 @@
     /* Destructor */
     ~EapDialogPlugin();
     
-    /* Check whether access is allowed, true is always returned */
+    /* Check whether access is allowed, true is always returned. 
+       (from HbDeviceDialogPlugin) */
     bool accessAllowed(const QString &deviceDialogType,
         const QVariantMap &parameters, const QVariantMap &securityInfo) const;
     
-    /* Creates the dialog widget */
+    /* Creates the dialog widget. (from HbDeviceDialogPluginInterface) */
     HbDeviceDialogInterface *createDeviceDialog(const QString &deviceDialogType,
         const QVariantMap &parameters);
     
     /* Returns the device dialog type */
     bool deviceDialogInfo(const QString &deviceDialogType,
         const QVariantMap &parameters, DeviceDialogInfo *info) const;
     
     /* Returns a list of dialog types that this plugin implements.
      * Only one dialog type is supported.
      */
     QStringList deviceDialogTypes() const;
     
-    /* Returns the possible plugin flags, there are none */
+    /* Returns the possible plugin flags, there are none. 
+       (from HbDeviceDialogPlugin) */
     PluginFlags pluginFlags() const;
     
-    /* Not supported */
+    /* Not supported. (from HbDeviceDialogPlugin)*/
     int error() const;
 
 private:
@@ -65,4 +82,6 @@
 
 };
 
+/*! @} */
+
 #endif // ___EAPDIALOG_H__
@@ -37,27 +52,29 @@
         const QVariantMap &parameters);
     
-    /* Returns the device dialog type */
+    /* Returns the device dialog type. (from HbDeviceDialogPlugin)*/
     bool deviceDialogInfo(const QString &deviceDialogType,
         const QVariantMap &parameters, DeviceDialogInfo *info) const;
@@ -37,27 +52,29 @@
     
     /* Returns a list of dialog types that this plugin implements.
-     * Only one dialog type is supported.
+     * Only one dialog type is supported. (from HbDeviceDialogPlugin)
      */
     QStringList deviceDialogTypes() const;